==> tempest2-testing-docker-1.4.0-javadoc.jar: tempest2/app.cash.tempest2/-view/index.md <==
[tempest2](../../index.md) / [app.cash.tempest2](../index.md) / [View](./index.md)

# View

`interface View<K : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, I : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>`

### Functions

| Name | Summary |
|---|---|
| [delete](delete.md) | `abstract fun delete(item: `[`I`](index.md#I)`, deleteExpression: `[`Expression`](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/enhanced/dynamodb/Expression.html)`? = null): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>Deletes [item](delete.md#app.cash.tempest2.View$delete(app.cash.tempest2.View.I, software.amazon.awssdk.enhanced.dynamodb.Expression)/item) from its DynamoDB table using [deleteExpression](delete.md#app.cash.tempest2.View$delete(app.cash.tempest2.View.I, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression). Any options specified in the [deleteExpression](delete.md#app.cash.tempest2.View$delete(app.cash.tempest2.View.I, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression) parameter will be overlaid on any constraints due to versioned attributes.`open fun delete(item: `[`I`](index.md#I)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [deleteKey](delete-key.md) | `abstract fun deleteKey(key: `[`K`](index.md#K)`, deleteExpression: `[`Expression`](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/enhanced/dynamodb/Expression.html)`? = null): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>Deletes the item identified by [key](delete-key.md#app.cash.tempest2.View$deleteKey(app.cash.tempest2.View.K, software.amazon.awssdk.enhanced.dynamodb.Expression)/key) from its DynamoDB table using [deleteExpression](delete-key.md#app.cash.tempest2.View$deleteKey(app.cash.tempest2.View.K, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression). Any options specified in the [deleteExpression](delete-key.md#app.cash.tempest2.View$deleteKey(app.cash.tempest2.View.K, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression) parameter will be overlaid on any constraints due to versioned attributes.`open fun deleteKey(key: `[`K`](index.md#K)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [load](load.md) | `abstract fun load(key: `[`K`](index.md#K)`, consistentReads: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false): `[`I`](index.md#I)`?`<br>Returns an item whose keys match those of the prototype key object given, or null if no such item exists.`open fun load(key: `[`K`](index.md#K)`): `[`I`](index.md#I)`?` |
| [save](save.md) | `abstract fun save(item: `[`I`](index.md#I)`, saveExpression: `[`Expression`](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/enhanced/dynamodb/Expression.html)`? = null): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>Saves an item in DynamoDB. This method uses [DynamoDbClient.putItem](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/services/dynamodb/DynamoDbClient.html#putItem(software.amazon.awssdk.services.dynamodb.model.PutItemRequest)) to clear and replace all attributes, including unmodeled ones, on save. Partial update, i.e. [DynamoDbClient.updateItem](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/services/dynamodb/DynamoDbClient.html#updateItem(software.amazon.awssdk.services.dynamodb.model.UpdateItemRequest)), is not supported yet.`open fun save(item: `[`I`](index.md#I)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inheritors

| Name | Summary |
|---|---|
| [InlineView](../-inline-view/index.md) | `interface InlineView<K : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, I : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> : `[`View`](./index.md)`<`[`K`](../-inline-view/index.md#K)`, `[`I`](../-inline-view/index.md#I)`>, `[`Scannable`](../-scannable/index.md)`<`[`K`](../-inline-view/index.md#K)`, `[`I`](../-inline-view/index.md#I)`>, `[`Queryable`](../-queryable/index.md)`<`[`K`](../-inline-view/index.md#K)`, `[`I`](../-inline-view/index.md#I)`>` |
| [LogicalTable](../-logical-table/index.md) | `interface LogicalTable<RI : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> : `[`View`](./index.md)`<`[`RI`](../-logical-table/index.md#RI)`, `[`RI`](../-logical-table/index.md#RI)`>, `[`InlineView.Factory`](../-inline-view/-factory/index.md)`, `[`SecondaryIndex.Factory`](../-secondary-index/-factory/index.md)<br>A collection of views on a DynamoDB table that makes it easy to model heterogeneous items using strongly typed data classes. |

==> tempest2-testing-docker-1.5.1-javadoc.jar: tempest2/app.cash.tempest2/-view/index.md <==
[tempest2](../../index.md) / [app.cash.tempest2](../index.md) / [View](./index.md)

# View

`interface View<K : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, I : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`>`

### Functions

| Name | Summary |
|---|---|
| [delete](delete.md) | `abstract fun delete(item: `[`I`](index.md#I)`, deleteExpression: `[`Expression`](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/enhanced/dynamodb/Expression.html)`? = null): `[`I`](index.md#I)`?`<br>Deletes [item](delete.md#app.cash.tempest2.View$delete(app.cash.tempest2.View.I, software.amazon.awssdk.enhanced.dynamodb.Expression)/item) from its DynamoDB table using [deleteExpression](delete.md#app.cash.tempest2.View$delete(app.cash.tempest2.View.I, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression). Any options specified in the [deleteExpression](delete.md#app.cash.tempest2.View$delete(app.cash.tempest2.View.I, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression) parameter will be overlaid on any constraints due to versioned attributes.`open fun delete(item: `[`I`](index.md#I)`): `[`I`](index.md#I)`?` |
| [deleteKey](delete-key.md) | `abstract fun deleteKey(key: `[`K`](index.md#K)`, deleteExpression: `[`Expression`](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/enhanced/dynamodb/Expression.html)`? = null): `[`I`](index.md#I)`?`<br>Deletes the item identified by [key](delete-key.md#app.cash.tempest2.View$deleteKey(app.cash.tempest2.View.K, software.amazon.awssdk.enhanced.dynamodb.Expression)/key) from its DynamoDB table using [deleteExpression](delete-key.md#app.cash.tempest2.View$deleteKey(app.cash.tempest2.View.K, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression). Any options specified in the [deleteExpression](delete-key.md#app.cash.tempest2.View$deleteKey(app.cash.tempest2.View.K, software.amazon.awssdk.enhanced.dynamodb.Expression)/deleteExpression) parameter will be overlaid on any constraints due to versioned attributes.`open fun deleteKey(key: `[`K`](index.md#K)`): `[`I`](index.md#I)`?` |
| [load](load.md) | `abstract fun load(key: `[`K`](index.md#K)`, consistentReads: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false): `[`I`](index.md#I)`?`<br>Returns an item whose keys match those of the prototype key object given, or null if no such item exists.`open fun load(key: `[`K`](index.md#K)`): `[`I`](index.md#I)`?` |
| [save](save.md) | `abstract fun save(item: `[`I`](index.md#I)`, saveExpression: `[`Expression`](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/enhanced/dynamodb/Expression.html)`? = null): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>Saves an item in DynamoDB. This method uses [DynamoDbClient.putItem](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/services/dynamodb/DynamoDbClient.html#putItem(software.amazon.awssdk.services.dynamodb.model.PutItemRequest)) to clear and replace all attributes, including unmodeled ones, on save. Partial update, i.e. [DynamoDbClient.updateItem](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/services/dynamodb/DynamoDbClient.html#updateItem(software.amazon.awssdk.services.dynamodb.model.UpdateItemRequest)), is not supported yet.`open fun save(item: `[`I`](index.md#I)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inheritors

| Name | Summary |
|---|---|
| [InlineView](../-inline-view/index.md) | `interface InlineView<K : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, I : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> : `[`View`](./index.md)`<`[`K`](../-inline-view/index.md#K)`, `[`I`](../-inline-view/index.md#I)`>, `[`Scannable`](../-scannable/index.md)`<`[`K`](../-inline-view/index.md#K)`, `[`I`](../-inline-view/index.md#I)`>, `[`Queryable`](../-queryable/index.md)`<`[`K`](../-inline-view/index.md#K)`, `[`I`](../-inline-view/index.md#I)`>` |
| [LogicalTable](../-logical-table/index.md) | `interface LogicalTable<RI : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> : `[`View`](./index.md)`<`[`RI`](../-logical-table/index.md#RI)`, `[`RI`](../-logical-table/index.md#RI)`>, `[`InlineView.Factory`](../-inline-view/-factory/index.md)`, `[`SecondaryIndex.Factory`](../-secondary-index/-factory/index.md)<br>A collection of views on a DynamoDB table that makes it easy to model heterogeneous items using strongly typed data classes. |
